pub struct AutoModerationTriggerMetadata {
pub allow_list: Option<Vec<String>>,
pub keyword_filter: Option<Vec<String>>,
pub presets: Option<Vec<AutoModerationKeywordPresetType>>,
pub mention_raid_protection_enabled: Option<bool>,
pub mention_total_limit: Option<u8>,
pub regex_patterns: Option<Vec<String>>,
}Expand description
Additional data used to determine whether a rule should be triggered.
Different fields are relevant based on the value of AutoModerationRule::trigger_type.
Fields
allow_list: Option<Vec<String>>Substrings that will be exempt from triggering the preset type.
keyword_filter: Option<Vec<String>>Substrings which will be searched for in content.
presets: Option<Vec<AutoModerationKeywordPresetType>>Internally pre-defined wordsets which will be searched for in content.
A keyword can be a phrase which contains multiple words. Wildcard symbols can be used to customize how each keyword will be matched. See Discord Docs/Keyword Matching Strategies.
mention_raid_protection_enabled: Option<bool>Whether to automatically detect mention raids.
mention_total_limit: Option<u8>Total number of unique role and user mentions allowed per message (Maximum of 50).
regex_patterns: Option<Vec<String>>Regular expression patterns which will be matched against content (Maximum of 10). Only Rust flavored regex is supported. Each regex pattern must be 260 characters or less.